
function OnMapInsert() //run as the entity is placed on an actual map, but before OnPostInit()
	GetWatchManager:Add(this, C_TIME_FOREVER); //always function offscreen
end


function OnInit() //run upon initialization
	
	//hint to the path-finding system that it can ignore this while computing paths if it needs to
	this:SetIsCreature(true); 
end

function OnPostInit() //run after being placed on a map

	this:GetBrainManager():Add("StandardBase","");
	
	AddPatrolGoals();
	
	LookAround();
	this:SetTurnSpeed(6); //turn instantly
  this:SetAcceleration(1);

	this:SetCollisionListenCategory(C_CATEGORY_PLAYER, true);
 
end




function LookAround()
	
	//we already chasing him?
	if (this:GetGoalManager():IsGoalActiveByName("ChasingPlayer")) then
		//we're already chasing him.  Should we stop?
	
		//if we're far away AND can't see him, yes, stop
	
		if (this:GetDistanceFromEntityByID(g_playerID) > 400
			and not this:HasLineOfSightToPosition(GetPlayer:GetPos(), true) ) then
		
			//he's not visible and more than 400 pixels away.  Stop.
			GetTextManager:Add("(panting) Where did he go?", this);
			this:SetDesiredSpeed(8); //walk speed again

			//cancel the chase, start patrolling
			this:GetGoalManager():RemoveAllSubgoals(); //stop whatever we were doing
			AddPatrolGoals();
			this:GetGoalManager():PushDelay(2000); //wait two seconds first
		
		else
		
			//the player is still in range.  Let's recalcuate our chase path.
			SetupPlayerChase();
		end
	
	else
	
		//not currently chasing player.  But should we?
		
		//is the player close?
		if (GetPlayer != nil and this:GetDistanceFromEntityByID(g_playerID) < 700
			and this:HasLineOfSightToPosition(GetPlayer:GetPos(), true)) then
				//We can see the player!
				this:SetDesiredSpeed(12); //start running
				SetupPlayerChase();
				GetTextManager:Add("I see you!", this);
			end

	end
		
	//call this function again, randomly chooses a time to look again
	Schedule(random(500,1000), this:GetID(), "LookAround()");

end

function SetupPlayerChase()

	//cancel other goals and start chasing the player.  
	
	this:GetGoalManager():RemoveAllSubgoals(); //stop whatever we were doing
	local goal = this:GetGoalManager():AddNewGoal("ChasingPlayer");
	goal:AddApproachAndSay("(breaths fire)", g_playerID, C_DISTANCE_INSIDE);
			
end

       

function OnKill() //run when removed

end


function AddPatrolGoals()
	
	local pointName = "point" .. random(1, 4); //a random number between 1 and 4. 
	
	this:GetGoalManager():AddApproach(GetEntityByName(pointName):GetID(), C_DISTANCE_CLOSE);
	this:GetGoalManager():AddRunScriptString("AddPatrolGoals()");
	
end


//vPosition, vVelocity and vNormal are Vector2's, depth and materialID are numbers, entity is a Entity, and state let's you know
//if this is a first contact or a persisting one. 
//if entity is nil, it is a collision with a TilePic

function OnCollision(vPosition, vVelocity, vNormal, depth, materialID, entity, state)

	 LogMsg("Hit the player!");
	 entity:RunFunction("OnDamage", vNormal, depth, nil, 5, 0, this); //let the player know we hit him and extra junk he may care about.  
end

