function OnInit() //run upon initialization

	this:SetIsCreature(true); //hint to engine to ignore us when calculating pathfinding
end

function OnMapInsert()

	//count how many eggs have been created
	
	if (this:VariableExists("g_eggCount")) then
		//global already exists.  Let's use it.
		_G.g_eggCount = g_eggCount + 1;
	else
		//no global exists yet, let's create it so all eggs can use it
		_G.g_eggCount = 1;  //the _G. is the only way to set a global
	end
end

function OnPostInit() //run during the entity's first logic update

	//let's not actually 'collide' with anything, otherwise the dragons could push us around
	this:SetCollisionCategories(C_CATEGORIES_NONE); //no collision at all

	//register to get OnCollision calls when the player walks though us.
	this:SetCollisionListenCategory(C_CATEGORY_PLAYER, true);
	
end

function OnKill() //run when removed

	RemoveEggFromGlobalCount();

end

function RemoveEggFromGlobalCount()

	if (this:VariableExists("m_removedEgg")) then
		//already removed it.
		return;
	end
	
	_G.g_eggCount = g_eggCount - 1;
	
	m_removedEgg = true;
end


//vPosition, vVelocity and vNormal are Vector2's, depth and materialID are numbers, entity is a Entity, and state let's you know
//if this is a first contact or a persisting one. 
//if entity is nil, it is a collision with a TilePic

function OnCollision(vPosition, vVelocity, vNormal, depth, materialID, entity, state)
	//if this is called, we must have hit the player, which will be passed as the "entity" var.

	//first, turn off our collision 'listening' so this won't get called again
	this:SetCollisionListenCategory(C_CATEGORY_PLAYER, false); //don't be notified anymore
     
	//sound effect
	local soundID = this:PlaySound("audio/gui/change_selection1.ogg");
	GetSoundManager:SetSpeedFactor(soundID, 0.5); //slow down the sound
	
	//scale down to nothing and then delete itself
	this:GetBrainManager():Add("Scale", "scalex=0.1;scaley=0.1;scale_speed_ms=500;delete_entity=true");

	//let the player know where he stands
	
	RemoveEggFromGlobalCount();
		
	if (g_eggCount > 0) then
		//still more eggs after this
		GetTextManager:Add("(egg collected, " .. g_eggCount .. " left)", entity);
	else
		//this is the last egg!
		GetTextManager:Add("You collected the last egg, Huzzah!  Uh.  You win?", entity);
	end

end