
RunScript("system/player_utils.lua"); //has some useful global functions, this is in base

function OnInit() //run upon initialization
	this:GetBrainManager():Add("StandardBase",""); //add this

	//hint to the path-finding system that it can ignore this while computing paths if it needs to
	this:SetIsCreature(true); 
end

function OnPostInit() //run during the entity's first logic update

	this:SetCategories(C_CATEGORIES_NONE); //clear the default C_CATEGORY_ENTITY category that is automatically set
	this:SetCategory(C_CATEGORY_PLAYER, true); //set the category we want to be
	
	this:SetDesiredSpeed(12);
   this:SetMaxMovementSpeed(12);
   this:SetAcceleration(1);
	LogMsg("Hi World! My name is " .. this:GetName() .. " and I like long romantic walks on the beach");

	this:SetTurnSpeed(6); //turn instantly.  Since we only have 1 graphic frame, it's weird
	//if we don't do this

	//Note: the "always" keyword means the key will always react, regardless of what else is 
	//also pressed. Without it, you couldn't shoot and walk at the same time

	GetInputManager:AddBinding("left,always", "OnLeft", this:GetID());
	GetInputManager:AddBinding("right,always", "OnRight", this:GetID());
	GetInputManager:AddBinding("up,always", "OnUp", this:GetID());
	GetInputManager:AddBinding("down,always", "OnDown", this:GetID());
	
	ResetKeys(); //our function to reset our local key input vars

	//let's have a function that gets run every logic tick
	this:SetRunUpdateEveryFrame(true);
end

function OnKill() //run when removed
	RemoveActivePlayerIfNeeded(this);
end

//this is run every logic tick, normally we don't need to do this, but the player is a special case
function Update(step)
	
	AssignPlayerToCameraIfNeeded(this);  //make us the official player and have the camera track us,
	//if we're not already, and if another entity doesn't already have this role
		
	//this function is in player_utils.lua
	local facing = ConvertKeysToFacing(m_bLeft, m_bRight, m_bUp, m_bDown); 
	
	if (facing != C_FACING_NONE) then
		//they are pressing towards a direction
		this:SetFacingTarget(facing); //turn towards the direction of the keys we pressed
		this:GetBrainManager():SetStateByName("Walk");
	else
		this:GetBrainManager():SetStateByName("Idle");
	end	
end

function ResetKeys()

	m_bLeft = false;
	m_bRight = false;
	m_bUp = false
	m_bDown = false;
end

function OnLeft(bKeyDown)
    m_bLeft = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnRight(bKeyDown)
    m_bRight = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnUp(bKeyDown)
    m_bUp = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnDown(bKeyDown)
    m_bDown = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

//entParent is whoever sent the damage, entObject is the actual damaging object/projectile if not nil
function OnDamage(normal, depth, entParent, strength, extra, entObject)
	
	
	if (this:VariableExists("m_isDead")) then
		//we're already dead.  ignore this
		return;
	end
	
	m_isDead = true; //create a variable so we know we're dead.
	
	//set it so we can't be controlled by input anymore
	GetInputManager:RemoveBindingsByEntity(this);
	
	//stop moving, in case we were
	ResetKeys();
	
	//flash red for a long time
	this:GetBrainManager():Add("ColorFlash", "pulse_rate=50;g=-200;b=-200;remove_brain_by_pulses=1000");

	this:GetGoalManager():AddSay("Aaaarrrrgggghhh!", C_FACING_NONE);
	this:GetGoalManager():AddSay("I guess the game is over.  Press Ctrl-Shift-R to restart or reinit " ..
		"the player by hitting F1 and then dragging him a few pixels.", C_FACING_NONE);
	
end
